.. include:: _common.rst

|name| documentation
====================

Introduction
------------

|name| is a Python library for performing operations on morphologies.

.. toctree::
   :titlesonly:

   install
   cookbook
   changelog


Reporting issues
----------------

|name| is currently maintained by the BlueBrain NSE team.

Should you face any issue with using it, please submit a ticket to the `issue tracker <https://bbpteam.epfl.ch/project/issues/browse/NSE>`_; or drop us an `email <mailto: bbp-ou-nse@groupes.epfl.ch>`_.
